@@ -42,7 +42,7 @@ func init() {
 	}
 
 	if discovery.Enabled() {
-		profile, err := discovery.GetDiscoveryPerformanceProfile()
+		profile, err := discovery.GetDiscoveryPerformanceProfile(NodesSelector)
 		if err == discovery.ErrProfileNotFound {
 			ProfileNotFound = true
 			return
@@ -59,6 +59,9 @@ func init() {
 		NodeSelectorLabels = profile.Spec.NodeSelector
 		if NodesSelector != "" {
 			keyValue := strings.Split(NodesSelector, "=")
+			if len(keyValue) == 1 {
+				keyValue = append(keyValue, "")
+			}
 			NodeSelectorLabels[keyValue[0]] = keyValue[1]
 		}
 	}
